==> cscec5b-dataexchange-api-3.0.1-20211105.085438-9-sources.jar: com/ejianc/business/dataexchange/vo/Project.java <==
package com.ejianc.business.dataexchange.vo;

import java.math.BigDecimal;

/**
 * 项目接口 实体
 * @author Brin
 * @since 2020-11-04 13:11:48
 */
public class Project   {

    private static final long serialVersionUID = 1L;
    
    private java.lang.String pkproject;
    private java.lang.String pkcorp;
    private java.lang.String vprojectcode;
    private java.lang.String vprojectname;
    private java.lang.String vshortname;
    private java.lang.String vmanager;
    private java.lang.String vmanagerphone;
    private java.lang.String vlocation;
    private java.math.BigDecimal ncontmny;
    private java.lang.Integer dr;

    public String getPkproject() {
        return pkproject;
    }

    public void setPkproject(String pkproject) {
        this.pkproject = pkproject;
    }

    public String getPkcorp() {
        return pkcorp;
    }

    public void setPkcorp(String pkcorp) {
        this.pkcorp = pkcorp;
    }

    public String getVprojectcode() {
        return vprojectcode;
    }

    public void setVprojectcode(String vprojectcode) {
        this.vprojectcode = vprojectcode;
    }

    public String getVprojectname() {
        return vprojectname;
    }

    public void setVprojectname(String vprojectname) {
        this.vprojectname = vprojectname;
    }

    public String getVshortname() {
        return vshortname;
    }

    public void setVshortname(String vshortname) {
        this.vshortname = vshortname;
    }

    public String getVmanager() {
        return vmanager;
    }

    public void setVmanager(String vmanager) {
        this.vmanager = vmanager;
    }

    public String getVmanagerphone() {
        return vmanagerphone;
    }

    public void setVmanagerphone(String vmanagerphone) {
        this.vmanagerphone = vmanagerphone;
    }

    public String getVlocation() {
        return vlocation;
    }

    public void setVlocation(String vlocation) {
        this.vlocation = vlocation;
    }

    public BigDecimal getNcontmny() {
        return ncontmny;
    }

    public void setNcontmny(BigDecimal ncontmny) {
        this.ncontmny = ncontmny;
    }

    public Integer getDr() {
        return dr;
    }

    public void setDr(Integer dr) {
        this.dr = dr;
    }
}

==> cscec5b-dataexchange-api-3.0.1-20221024.044922-61-sources.jar: com/ejianc/business/dataexchange/vo/Project.java <==
package com.ejianc.business.dataexchange.vo;

import java.math.BigDecimal;

/**
 * 项目接口 实体
 * @author Brin
 * @since 2020-11-04 13:11:48
 */
public class Project   {

    private static final long serialVersionUID = 1L;
    
    private java.lang.String pkproject;
    private java.lang.String pkcorp;
    private java.lang.String realpkcorp;
    private java.lang.String realcorpname;
    private java.lang.String vprojectcode;
    private java.lang.String vprojectname;
    private java.lang.String vshortname;
    private java.lang.String vmanager;
    private java.lang.String vmanagerphone;
    private java.lang.String pkArea;
    private java.lang.String areaName;
    private java.lang.String pkAddress;
    private java.lang.String addrName;
    private java.lang.String vlocation;
    private java.math.BigDecimal ncontmny;
    private java.lang.Integer dr;

    public String getPkproject() {
        return pkproject;
    }

    public void setPkproject(String pkproject) {
        this.pkproject = pkproject;
    }

    public String getPkcorp() {
        return pkcorp;
    }

    public void setPkcorp(String pkcorp) {
        this.pkcorp = pkcorp;
    }

    public String getRealpkcorp() {
        return realpkcorp;
    }

    public void setRealpkcorp(String realpkcorp) {
        this.realpkcorp = realpkcorp;
    }

    public String getRealcorpname() {
        return realcorpname;
    }

    public void setRealcorpname(String realcorpname) {
        this.realcorpname = realcorpname;
    }

    public String getVprojectcode() {
        return vprojectcode;
    }

    public void setVprojectcode(String vprojectcode) {
        this.vprojectcode = vprojectcode;
    }

    public String getVprojectname() {
        return vprojectname;
    }

    public void setVprojectname(String vprojectname) {
        this.vprojectname = vprojectname;
    }

    public String getVshortname() {
        return vshortname;
    }

    public void setVshortname(String vshortname) {
        this.vshortname = vshortname;
    }

    public String getVmanager() {
        return vmanager;
    }

    public void setVmanager(String vmanager) {
        this.vmanager = vmanager;
    }

    public String getVmanagerphone() {
        return vmanagerphone;
    }

    public void setVmanagerphone(String vmanagerphone) {
        this.vmanagerphone = vmanagerphone;
    }

    public String getPkArea() {
        return pkArea;
    }

    public void setPkArea(String pkArea) {
        this.pkArea = pkArea;
    }

    public String getAreaName() {
        return areaName;
    }

    public void setAreaName(String areaName) {
        this.areaName = areaName;
    }

    public String getPkAddress() {
        return pkAddress;
    }

    public void setPkAddress(String pkAddress) {
        this.pkAddress = pkAddress;
    }

    public String getAddrName() {
        return addrName;
    }

    public void setAddrName(String addrName) {
        this.addrName = addrName;
    }

    public String getVlocation() {
        return vlocation;
    }

    public void setVlocation(String vlocation) {
        this.vlocation = vlocation;
    }

    public BigDecimal getNcontmny() {
        return ncontmny;
    }

    public void setNcontmny(BigDecimal ncontmny) {
        this.ncontmny = ncontmny;
    }

    public Integer getDr() {
        return dr;
    }

    public void setDr(Integer dr) {
        this.dr = dr;
    }
}
